@@ -13,6 +13,10 @@ pub fn is_payment_nonce(attr: &syn::Attribute) -> bool {
     is_attribute_with_no_args(attr, ATTR_PAYMENT_NONCE)
 }
 
+pub fn is_payment_multi(attr: &syn::Attribute) -> bool {
+    is_attribute_with_no_args(attr, ATTR_PAYMENT_MULTI)
+}
+
 pub fn is_var_args(attr: &syn::Attribute) -> bool {
     is_attribute_with_no_args(attr, ATTR_VAR_ARGS)
 }
